@@ -10,8 +10,11 @@ from bin.jpgtest import JPGTest
 from bin.pagenumbertest import PageNumberTest
 from bin.pngsizetest import ImageSizeTest
 from bin.ellipsetest import EllipseTest
+from bin.transformtest import TransformTest
+from bin.htmltest import HtmlTest
 
 def main():
+    """
     print "Running TextTest"
     TextTest()
     print "Running TrueTypeTest"
@@ -36,7 +39,10 @@ def main():
     ImageSizeTest()
     print "Running EllipseTest"
     EllipseTest()
-
+    print "Running TransormTest"
+    TransformTest()
+    """
+    HtmlTest()
 
 if __name__ == '__main__':
     main()
